@@ -260,16 +260,15 @@ sub _cmp_col {
     #
 
     my $class = shift;
-    my $col = shift;
+    my $data_type = shift;
     my $_v1 = shift;
     my $_v2 = shift;
+    my %opt = @_;
 
     return undef
 	unless (defined $_v1 && defined $_v2);
 
-    my $cmp;
-
-    my ($type, $is_array, $is_struct) = Elive::Util::parse_type($class->property_types->{$col});
+    my ($type, $is_array, $is_struct) = Elive::Util::parse_type($data_type);
     my @v1 = ($is_array? @$_v1: ($_v1));
     my @v2 = ($is_array? @$_v2: ($_v2));
 
@@ -279,59 +278,72 @@ sub _cmp_col {
 	#
 	for (@v1, @v2) {
 	    #
-	    # autobless references
-	    if (Scalar::Util::refaddr($_)) {
-
-		$_ = $type->stringify($_);
-	    }
+	    # stringify references
+	    #
+	    $_ = $type->stringify($_)
 	}
     }
 
-    @v1 = sort @v1;
-    @v2 = sort @v2;
-
     #
     # unequal arrays lengths => unequal
     #
 
-    $cmp ||= scalar @v1 <=> scalar @v2;
+    my $cmp = scalar @v1 <=> scalar @v2;
 
-    if ($cmp) {
-    }
-    elsif (scalar @v1 == 0) {
+    unless ($cmp) {
 
-	#
-	# Empty arrays => equal
-	#
+	if (scalar @v1 == 0) {
 
-	$cmp = undef;
-    }
-    else {
-	#
-	# compare values
-	#
-	for (my $i = 0; $i < @v1; $i++) {
+	    #
+	    # Empty arrays => equal
+	    #
 
-	    my $v1 = $v1[$i];
-	    my $v2 = $v2[$i];
+	    $cmp = undef;
+	}
+	else {
+	    #
+	    # arrays are of equal lengths. compare values
+	    #
 
-	    if ($is_struct || $type =~ m{^(Str|Enum|HiResDate)}i) {
-		# string comparision. works on simple strings and
-		# stringified entities. Also used for hires dates
-		# integer comparision may result in arithmetic overflow
-		# 
-		$cmp ||= $v1 cmp $v2;
+	    if ($is_array) {
+
+		#
+		# Order of elements does not matter
+		#
+
+		@v1 = sort {$class->_cmp_col($type, $a, $b, %opt)} @v1;
+		@v2 = sort {$class->_cmp_col($type, $a, $b, %opt)} @v2;
 	    }
-	    elsif ($type =~ m{^Bool}i) {
-		# boolean comparison
-		$cmp ||= ($v1? 1: 0) <=> ($v2? 1: 0);
-	    }
-	    elsif ($type =~ m{^Int}i) {
-		# int comparision
-		$cmp ||= $v1 <=> $v2;
-	    }
-	    else {
-		die "class $class: column $col has unknown type: $type";
+
+	    for (my $i = 0; $i < @v1; $i++) {
+
+		my $v1 = $v1[$i];
+		my $v2 = $v2[$i];
+
+		if ($is_struct || $type =~ m{^(Str|Enum|HiResDate)}i) {
+		    #
+		    # string comparision. works on simple strings and
+		    # stringified entities. Also used for hires dates
+		    # integer comparision may result in arithmetic overflow
+		    #
+		    $_ = Elive::Util::_freeze($_, $type)
+			for ($v1, $v2);
+
+		    $cmp ||= ($opt{case_insensitive}
+			      ? uc($v1) cmp uc($v2)
+			      : $v1 cmp $v2);
+		}
+		elsif ($type =~ m{^Bool}i) {
+		    # boolean comparison
+		    $cmp ||= ($v1? 1: 0) <=> ($v2? 1: 0);
+		}
+		elsif ($type =~ m{^Int}i) {
+		    # int comparision
+		    $cmp ||= $v1 <=> $v2;
+		}
+		else {
+		    die "class $class: unknown type: $type";
+		}
 	    }
 	}
     }
@@ -419,7 +431,8 @@ sub set {
 	    if (defined $old_val && !defined $data{$_}) {
 		die "attempt to delete primary key";
                }
-	    elsif ($self->_cmp_col($_, $old_val, $data{$_})) {
+	    elsif ($self->_cmp_col($self->property_types->{$_},
+				   $old_val, $data{$_})) {
 		die "attempt to update primary key";
 	    }
 	}
